@@ -10,29 +10,19 @@ from apigee.crypto import (ENCRYPTED_HEADER_BEGIN, ENCRYPTED_HEADER_END,
                            decrypt_message, encrypt_message, is_encrypted)
 
 CREATE_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps'
-DELETE_KEYVALUEMAP_FROM_AN_ENVIRONMENT_PATH = (
-    '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}'
-)
-DELETE_KEYVALUEMAP_ENTRY_IN_AN_ENVIRONMENT_PATH = (
-    '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/entries/{entry_name}'
-)
-GET_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH = (
-    '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}'
-)
+DELETE_KEYVALUEMAP_FROM_AN_ENVIRONMENT_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}'
+DELETE_KEYVALUEMAP_ENTRY_IN_AN_ENVIRONMENT_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/entries/{entry_name}'
+GET_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}'
 GET_A_KEYS_VALUE_IN_AN_ENVIRONMENT_SCOPED_KEYVALUEMAP_PATH = (
     '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/entries/{entry_name}'
 )
 LIST_KEYVALUEMAPS_IN_AN_ENVIRONMENT_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps'
-UPDATE_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH = (
-    '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}'
+UPDATE_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}'
+CREATE_AN_ENTRY_IN_AN_ENVIRONMENT_SCOPED_KVM_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/entries'
+UPDATE_AN_ENTRY_IN_AN_ENVIRONMENT_SCOPED_KVM_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/entries/{entry_name}'
+LIST_KEYS_IN_AN_ENVIRONMENT_SCOPED_KEYVALUEMAP_PATH = (
+    '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/keys?startkey={startkey}&count={count}'
 )
-CREATE_AN_ENTRY_IN_AN_ENVIRONMENT_SCOPED_KVM_PATH = (
-    '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/entries'
-)
-UPDATE_AN_ENTRY_IN_AN_ENVIRONMENT_SCOPED_KVM_PATH = (
-    '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/entries/{entry_name}'
-)
-LIST_KEYS_IN_AN_ENVIRONMENT_SCOPED_KEYVALUEMAP_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/keyvaluemaps/{name}/keys?startkey={startkey}&count={count}'
 
 
 class KeyvaluemapsSerializer:
@@ -88,9 +78,7 @@ class Keyvaluemaps:
         self._map_name = value
 
     def create_keyvaluemap_in_an_environment(self, environment, request_body):
-        uri = CREATE_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment
-        )
+        uri = CREATE_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment)
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         body = json.loads(request_body)
         resp = requests.post(uri, headers=hdrs, json=body)
@@ -98,9 +86,7 @@ class Keyvaluemaps:
         return resp
 
     def delete_keyvaluemap_from_an_environment(self, environment):
-        uri = DELETE_KEYVALUEMAP_FROM_AN_ENVIRONMENT_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name
-        )
+        uri = DELETE_KEYVALUEMAP_FROM_AN_ENVIRONMENT_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name)
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
@@ -108,11 +94,7 @@ class Keyvaluemaps:
 
     def delete_keyvaluemap_entry_in_an_environment(self, environment, entry_name):
         uri = DELETE_KEYVALUEMAP_ENTRY_IN_AN_ENVIRONMENT_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            environment=environment,
-            name=self._map_name,
-            entry_name=entry_name,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name, entry_name=entry_name
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
@@ -120,9 +102,7 @@ class Keyvaluemaps:
         return resp
 
     def get_keyvaluemap_in_an_environment(self, environment):
-        uri = GET_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name
-        )
+        uri = GET_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name)
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
@@ -130,11 +110,7 @@ class Keyvaluemaps:
 
     def get_a_keys_value_in_an_environment_scoped_keyvaluemap(self, environment, entry_name):
         uri = GET_A_KEYS_VALUE_IN_AN_ENVIRONMENT_SCOPED_KEYVALUEMAP_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            environment=environment,
-            name=self._map_name,
-            entry_name=entry_name,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name, entry_name=entry_name
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
@@ -142,18 +118,14 @@ class Keyvaluemaps:
         return resp
 
     def list_keyvaluemaps_in_an_environment(self, environment, prefix=None, format='json'):
-        uri = LIST_KEYVALUEMAPS_IN_AN_ENVIRONMENT_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment
-        )
+        uri = LIST_KEYVALUEMAPS_IN_AN_ENVIRONMENT_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment)
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return KeyvaluemapsSerializer().serialize_details(resp, format, prefix=prefix)
 
     def update_keyvaluemap_in_an_environment(self, environment, request_body):
-        uri = UPDATE_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name
-        )
+        uri = UPDATE_KEYVALUEMAP_IN_AN_ENVIRONMENT_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name)
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         body = json.loads(request_body)
         resp = requests.post(uri, headers=hdrs, json=body)
@@ -172,11 +144,7 @@ class Keyvaluemaps:
 
     def update_an_entry_in_an_environment_scoped_kvm(self, environment, entry_name, updated_value):
         uri = UPDATE_AN_ENTRY_IN_AN_ENVIRONMENT_SCOPED_KVM_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            environment=environment,
-            name=self._map_name,
-            entry_name=entry_name,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name, entry_name=entry_name
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
         body = {'name': entry_name, 'value': updated_value}
@@ -186,12 +154,7 @@ class Keyvaluemaps:
 
     def list_keys_in_an_environment_scoped_keyvaluemap(self, environment, startkey, count):
         uri = LIST_KEYS_IN_AN_ENVIRONMENT_SCOPED_KEYVALUEMAP_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL,
-            org=self._org_name,
-            environment=environment,
-            name=self._map_name,
-            startkey=startkey,
-            count=count,
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._map_name, startkey=startkey, count=count
         )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
@@ -214,15 +177,7 @@ class Keyvaluemaps:
             self.create_an_entry_in_an_environment_scoped_kvm(environment, entry['name'], entry['value'])
 
     def _delete_entries(self, environment, deleted_keys):
-        for idx, entry in enumerate(
-            tqdm(
-                deleted_keys,
-                desc='Deleting',
-                unit='entries',
-                bar_format='{l_bar}{bar:32}{r_bar}{bar:-10b}',
-                leave=False,
-            )
-        ):
+        for idx, entry in enumerate(tqdm(deleted_keys, desc='Deleting', unit='entries', bar_format='{l_bar}{bar:32}{r_bar}{bar:-10b}', leave=False)):
             self.delete_keyvaluemap_entry_in_an_environment(environment, entry['name'])
 
     @staticmethod
@@ -272,13 +227,7 @@ class Keyvaluemaps:
                 self._delete_entries(environment, deleted_keys)
                 console.echo('Removed entries.')
             if updated_loc_kvm['entry']:
-                for entry in tqdm(
-                    updated_loc_kvm['entry'],
-                    desc='Updating',
-                    unit='entries',
-                    bar_format='{l_bar}{bar:32}{r_bar}{bar:-10b}',
-                    leave=False,
-                ):
+                for entry in tqdm(updated_loc_kvm['entry'], desc='Updating', unit='entries', bar_format='{l_bar}{bar:32}{r_bar}{bar:-10b}', leave=False):
                     self._create_or_update_entry(environment, entry)
                 console.echo('Updated entries.')
             if not deleted_keys and not updated_loc_kvm['entry']:
