@@ -8,7 +8,5 @@ def silent_callback(ctx, param, value):
 
 
 def common_silent_options(func):
-    func = click.option(
-        '--silent', show_default='toggle silent output', flag_value=True, default=False, callback=silent_callback
-    )(func)
+    func = click.option('--silent', show_default='toggle silent output', flag_value=True, default=False, callback=silent_callback)(func)
     return func
